@@ -2,7 +2,7 @@
  *  filemgr.cpp	- implementation of class FileMgr used for pooling file
  *  					handles
  *
- * $Id: filemgr.cpp 1864 2005-11-20 06:06:40Z scribe $
+ * $Id: filemgr.cpp 2108 2007-10-13 20:35:02Z scribe $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -377,6 +377,12 @@ int FileMgr::createParent(const char *pName) {
 }
 	
 
+int FileMgr::openFileReadOnly(const char *fName) {
+	int fd = ::open(fName, O_RDONLY|O_BINARY, S_IREAD|S_IWRITE|S_IRGRP|S_IROTH);
+	return fd;
+}
+
+
 int FileMgr::createPathAndFile(const char *fName) {
 	int fd;
 	
@@ -393,7 +399,7 @@ int FileMgr::copyFile(const char *sourceFile, const char *targetFile) {
 	int sfd, dfd, len;
 	char buf[4096];
 
-	if ((sfd = ::open(sourceFile, O_RDONLY|O_BINARY)) < 1)
+	if ((sfd = ::open(sourceFile, O_RDONLY|O_BINARY, S_IREAD|S_IWRITE|S_IRGRP|S_IROTH)) < 1)
 		return -1;
 	if ((dfd = createPathAndFile(targetFile)) < 1)
 		return -1;
@@ -429,6 +435,8 @@ char FileMgr::getLine(FileDesc *fDesc, SWBuf &line) {
 		more = false;
 		long index = fDesc->seek(0, SEEK_CUR);
 		len = fDesc->read(chunk, 254);
+
+		// assert we have a readable file (not a directory)
 		if (len < 1)
 			break;
 
@@ -441,15 +449,13 @@ char FileMgr::getLine(FileDesc *fDesc, SWBuf &line) {
 			}
 		}
 
-		// assert we have a readable file (not a directory)
-		if (len < 0)
-			break;
-
 		// find the end
 		int end;
 		for (end = start; ((end < (len-1)) && (chunk[end] != 10)); end++);
-		if (end >= 253)
+	
+		if ((chunk[end] != 10) && (len == 254)) {
 			more = true;
+		}
 		index += (end + 1);
 
 		// reposition to next valid place to read
@@ -490,7 +496,7 @@ char FileMgr::isDirectory(const char *path) {
 int FileMgr::copyDir(const char *srcDir, const char *destDir) {
 	DIR *dir;
 	struct dirent *ent;
-	if (dir = opendir(srcDir)) {
+	if ((dir = opendir(srcDir))) {
 		rewinddir(dir);
 		while ((ent = readdir(dir))) {
 			if ((strcmp(ent->d_name, ".")) && (strcmp(ent->d_name, ".."))) {
