@@ -151,9 +151,10 @@ void RawStr::getIDXBuf(long ioffset, char **buf)
 
 signed char RawStr::findOffset(const char *ikey, long *start, unsigned short *size, long away, long *idxoff)
 {
-	char *trybuf, *key = 0, quitflag = 0;
+	char *trybuf, *maxbuf, *key = 0, quitflag = 0;
 	signed char retval = -1;
 	long headoff, tailoff, tryoff = 0, maxoff = 0;
+	int diff = 0;
 
 	if (idxfd->getFd() >=0) {
 		tailoff = maxoff = idxfd->seek(0, SEEK_END) - 6;
@@ -164,10 +165,14 @@ signed char RawStr::findOffset(const char *ikey, long *start, unsigned short *si
 			stdstr(&key, ikey, 3);
 			toupperstr_utf8(key, strlen(key)*3);
 
-			trybuf = 0;
+			int keylen = strlen(key);
+			bool substr = false;
 
+			trybuf = maxbuf = 0;
+			getIDXBuf(maxoff, &maxbuf);
+                        
 			while (headoff < tailoff) {
-				tryoff = (lastoff == -1) ? headoff + ((((tailoff / 6) - (headoff / 6))) / 2) * 6 : lastoff; 
+				tryoff = (lastoff == -1) ? headoff + ((((tailoff / 6) - (headoff / 6))) / 2) * 6 : lastoff;
 				lastoff = -1;
 				getIDXBuf(tryoff, &trybuf);
 
@@ -176,24 +181,36 @@ signed char RawStr::findOffset(const char *ikey, long *start, unsigned short *si
 					retval = -1;
 					break;
 				}
-					
-				if (!strcmp(key, trybuf))
+
+				diff = strcmp(key, trybuf);
+
+				if (!diff)
 					break;
 
-				int diff = strcmp(key, trybuf);
+				if (!strncmp(trybuf, key, keylen)) substr = true;
+
 				if (diff < 0)
 					tailoff = (tryoff == headoff) ? headoff : tryoff;
 				else headoff = tryoff;
+
 				if (tailoff == headoff + 6) {
 					if (quitflag++)
 						headoff = tailoff;
 				}
 			}
-			if (headoff >= tailoff)
+
+			// didn't find exact match
+			if (headoff >= tailoff) {
 				tryoff = headoff;
+				if (!substr && ((tryoff != maxoff)||(strncmp(key, maxbuf, keylen)<0))) {
+					away--;	// if our entry doesn't startwith our key, prefer the previous entry over the next
+				}
+			}
 			if (trybuf)
 				free(trybuf);
 			delete [] key;
+                        if (maxbuf)
+                        	free(maxbuf);
 		}
 		else	tryoff = 0;
 
@@ -332,6 +349,7 @@ void RawStr::readText(long istart, unsigned short *isize, char **idxbuf, SWBuf &
 	do {
 		if (*idxbuf)
 			delete [] *idxbuf;
+
 		buf = "";
 		buf.setFillByte(0);
 		buf.setSize(++(*isize));
