@@ -3,8 +3,8 @@
  *				cipher utilities.
  */
 
-#include <string.h>
 #include <stdlib.h>
+#include <string.h>
 #include <swcipher.h>
 
 SWORD_NAMESPACE_START
@@ -31,7 +31,7 @@ SWCipher::~SWCipher()
 }
 
 
-char *SWCipher::Buf(const char *ibuf, unsigned int ilen)
+char *SWCipher::Buf(const char *ibuf, unsigned long ilen)
 {
 	if (ibuf) {
 	
@@ -55,14 +55,14 @@ char *SWCipher::Buf(const char *ibuf, unsigned int ilen)
 }
 
 
-char *SWCipher::cipherBuf(unsigned int *ilen, const char *ibuf)
+char *SWCipher::cipherBuf(unsigned long *ilen, const char *ibuf)
 {
 	if (ibuf) {
 	
 		if (buf)
 			free(buf);
 			
-		buf = (char *) malloc(*ilen);
+		buf = (char *) malloc(*ilen+1);
 		memcpy(buf, ibuf, *ilen);
 		len = *ilen;
 		cipher = true;
@@ -70,7 +70,7 @@ char *SWCipher::cipherBuf(unsigned int *ilen, const char *ibuf)
 
 	Encode();
 
-	*ilen = (short)len;
+	*ilen = len;
 	return buf;
 }
 
@@ -87,7 +87,7 @@ void SWCipher::Encode(void)
 {
 	if (!cipher) {
 		work = master;
-		for (int i = 0; i < len; i++)
+		for (unsigned long i = 0; i < len; i++)
 			buf[i] = work.encrypt(buf[i]);
 		cipher = true;
 	}
@@ -106,8 +106,10 @@ void SWCipher::Decode(void)
 {
 	if (cipher) {
 		work = master;
-		for (int i = 0; i < len; i++)
+		unsigned long i;
+		for (i = 0; i < len; i++)
 			buf[i] = work.decrypt(buf[i]);
+		buf[i] = 0;
 		cipher = false;
 	}
 }
