@@ -59,7 +59,7 @@ char UTF8HTML::processText(SWBuf &text, const SWKey *key, const SWModule *module
           from += subsequent;
           text += '&';
           text += '#';
-	  sprintf(digit, "%d", ch);
+	  sprintf(digit, "%ld", ch);
 		for (char *dig = digit; *dig; dig++)
 			text += *dig;
 		text += ';';
