@@ -68,8 +68,8 @@ const char UTF8Transliterator::optionstring[NUMTARGETSCRIPTS][16] = {
         "Ogham",
         "Thaana",
 	"Glagolitic",
-        "Tengwar",
-        "Cirth"
+//        "Tengwar",
+//        "Cirth"
 };
 
 const char UTF8Transliterator::optName[] = "Transliteration";
@@ -133,16 +133,16 @@ void UTF8Transliterator::Load(UErrorCode &status)
 #ifndef _ICUSWORD_
 	static const char translit_swordindex[] = "translit_swordindex";
 	
-	UResourceBundle *bundle, *transIDs, *colBund;
+	UResourceBundle *bundle = 0, *transIDs = 0, *colBund = 0;
 	bundle = ures_openDirect(SW_RESDATA, translit_swordindex, &status);
 	if (U_FAILURE(status)) {
-		SWLog::getSystemLog()->logError("no resource index to load");
-		SWLog::getSystemLog()->logError("status %s", u_errorName(status));
+		SWLog::getSystemLog()->logError("UTF8Transliterator: ICU: no resource index to load");
+		SWLog::getSystemLog()->logError("UTF8Transliterator: ICU: status %s", u_errorName(status));
 		return;
 	}
 
 	transIDs = ures_getByKey(bundle, SW_RB_RULE_BASED_IDS, 0, &status);
-	UParseError parseError;
+	//UParseError parseError;
 
 	int32_t row, maxRows;
 	if (U_SUCCESS(status)) {
@@ -154,7 +154,7 @@ void UTF8Transliterator::Load(UErrorCode &status)
 				UnicodeString id = ures_getUnicodeStringByIndex(colBund, 0, &status);
                         	UChar type = ures_getUnicodeStringByIndex(colBund, 1, &status).charAt(0);
 				UnicodeString resString = ures_getUnicodeStringByIndex(colBund, 2, &status);
-                        	SWLog::getSystemLog()->logInformation("ok so far");
+                        	SWLog::getSystemLog()->logDebug("ok so far");
 
 				 if (U_SUCCESS(status)) {
 					switch (type) {
@@ -163,15 +163,15 @@ void UTF8Transliterator::Load(UErrorCode &status)
 						// 'file' or 'internal';
 						// row[2]=resource, row[3]=direction
 						{
-							UBool visible = (type == 0x0066 /*f*/);
+							//UBool visible = (type == 0x0066 /*f*/);
 							UTransDirection dir =
 								(ures_getUnicodeStringByIndex(colBund, 3, &status).charAt(0) ==
 								0x0046 /*F*/) ?
 								UTRANS_FORWARD : UTRANS_REVERSE;
 		                                        //registry->put(id, resString, dir, visible);
-							SWLog::getSystemLog()->logInformation("instantiating %s ...", resString.getBuffer());
+							SWLog::getSystemLog()->logDebug("instantiating %s ...", resString.getBuffer());
 					    		registerTrans(id, resString, dir, status);
-							SWLog::getSystemLog()->logInformation("done.");
+							SWLog::getSystemLog()->logDebug("done.");
 	                                	}
 						break;
 					case 0x61: // 'a'
@@ -180,16 +180,16 @@ void UTF8Transliterator::Load(UErrorCode &status)
                                 		break;
 					}
         	                 }
-                	         else SWLog::getSystemLog()->logError("Failed to get resString");
+                	         else SWLog::getSystemLog()->logError("UTF8Transliterator: ICU: Failed to get resString");
 	                }
-			else SWLog::getSystemLog()->logError("Failed to get row");
+			else SWLog::getSystemLog()->logError("UTF8Transliterator: ICU: Failed to get row");
 			ures_close(colBund);
 		}
 	}
 	else
 	{
-		SWLog::getSystemLog()->logError("no resource index to load");
-		SWLog::getSystemLog()->logError("status %s", u_errorName(status));
+		SWLog::getSystemLog()->logError("UTF8Transliterator: ICU: no resource index to load");
+		SWLog::getSystemLog()->logError("UTF8Transliterator: ICU: status %s", u_errorName(status));
 	}
 
 	ures_close(transIDs);
@@ -202,7 +202,7 @@ void  UTF8Transliterator::registerTrans(const UnicodeString& ID, const UnicodeSt
 		UTransDirection dir, UErrorCode &status )
 {
 #ifndef _ICUSWORD_
-		SWLog::getSystemLog()->logInformation("registering ID locally %s", ID.getBuffer());
+		SWLog::getSystemLog()->logDebug("registering ID locally %s", ID.getBuffer());
 		SWTransData swstuff;
 		swstuff.resource = resource;
 		swstuff.dir = dir;
@@ -220,7 +220,7 @@ bool UTF8Transliterator::checkTrans(const UnicodeString& ID, UErrorCode &status
 		if (!U_FAILURE(status))
 		{
 			// already have it, clean up and return true
-			SWLog::getSystemLog()->logInformation("already have it %s", ID.getBuffer());
+			SWLog::getSystemLog()->logDebug("already have it %s", ID.getBuffer());
 			delete trans;
 			return true;
 		}
@@ -229,13 +229,13 @@ bool UTF8Transliterator::checkTrans(const UnicodeString& ID, UErrorCode &status
 	SWTransMap::iterator swelement;
 	if ((swelement = transMap.find(ID)) != transMap.end())
 	{
-		SWLog::getSystemLog()->logInformation("found element in map");
+		SWLog::getSystemLog()->logDebug("found element in map");
 		SWTransData swstuff = (*swelement).second;
 		UParseError parseError;
 		//UErrorCode status;
 		//std::cout << "unregistering " << ID << std::endl;
 		//Transliterator::unregister(ID);
-		SWLog::getSystemLog()->logInformation("resource is %s", swstuff.resource.getBuffer());
+		SWLog::getSystemLog()->logDebug("resource is %s", swstuff.resource.getBuffer());
 
 		// Get the rules
 		//std::cout << "importing: " << ID << ", " << resource << std::endl;
@@ -246,8 +246,8 @@ bool UTF8Transliterator::checkTrans(const UnicodeString& ID, UErrorCode &status
 		//parser.parse(rules, isReverse ? UTRANS_REVERSE : UTRANS_FORWARD,
 		//        parseError, status);
 		if (U_FAILURE(status)) {
-			SWLog::getSystemLog()->logError("Failed to get rules");
-			SWLog::getSystemLog()->logError("status %s", u_errorName(status));
+			SWLog::getSystemLog()->logError("UTF8Transliterator: ICU: Failed to get rules");
+			SWLog::getSystemLog()->logError("UTF8Transliterator: ICU: status %s", u_errorName(status));
 			return false;
 		}
 
@@ -255,13 +255,13 @@ bool UTF8Transliterator::checkTrans(const UnicodeString& ID, UErrorCode &status
 		Transliterator *trans = Transliterator::createFromRules(ID, rules, swstuff.dir,
 			parseError,status);
 		if (U_FAILURE(status)) {
-			SWLog::getSystemLog()->logError("Failed to create transliterator");
-			SWLog::getSystemLog()->logError("status %s", u_errorName(status));
-			SWLog::getSystemLog()->logError("Parse error: line %s", parseError.line);
-			SWLog::getSystemLog()->logError("Parse error: offset %d", parseError.offset);
-			SWLog::getSystemLog()->logError("Parse error: preContext %s", *parseError.preContext);
-			SWLog::getSystemLog()->logError("Parse error: postContext %s", *parseError.postContext);
-			SWLog::getSystemLog()->logError("rules were");
+			SWLog::getSystemLog()->logError("UTF8Transliterator: ICU: Failed to create transliterator");
+			SWLog::getSystemLog()->logError("UTF8Transliterator: ICU: status %s", u_errorName(status));
+			SWLog::getSystemLog()->logError("UTF8Transliterator: ICU: Parse error: line %s", parseError.line);
+			SWLog::getSystemLog()->logError("UTF8Transliterator: ICU: Parse error: offset %d", parseError.offset);
+			SWLog::getSystemLog()->logError("UTF8Transliterator: ICU: Parse error: preContext %s", *parseError.preContext);
+			SWLog::getSystemLog()->logError("UTF8Transliterator: ICU: Parse error: postContext %s", *parseError.postContext);
+			SWLog::getSystemLog()->logError("UTF8Transliterator: ICU: rules were");
 //			SWLog::getSystemLog()->logError((const char *)rules);
 			return false;
 		}
@@ -349,7 +349,7 @@ char UTF8Transliterator::processText(SWBuf &text, const SWKey *key, const SWModu
                         scripts[i] = false;
                 }
 
-                for (i = 0; i < len; i++) {
+                for (i = 0; i < (unsigned long)len; i++) {
                         j = ublock_getCode(source[i]);
 			scripts[SE_LATIN] = true;
 			switch (j) {
@@ -771,14 +771,14 @@ char UTF8Transliterator::processText(SWBuf &text, const SWKey *key, const SWModu
 			}
 		}
 
-		if (scripts[SE_TENGWAR]) {
-			addTrans("Tengwar-Latin", &ID);
-			scripts[SE_LATIN] = true;
-		}
-		if (scripts[SE_CIRTH]) {
-			addTrans("Cirth-Latin", &ID);
-			scripts[SE_LATIN] = true;
-		}
+//		if (scripts[SE_TENGWAR]) {
+//			addTrans("Tengwar-Latin", &ID);
+//			scripts[SE_LATIN] = true;
+//		}
+//		if (scripts[SE_CIRTH]) {
+//			addTrans("Cirth-Latin", &ID);
+//			scripts[SE_LATIN] = true;
+//		}
 
 		if (scripts[SE_LATIN]) {
                 switch (option) {
@@ -851,12 +851,12 @@ char UTF8Transliterator::processText(SWBuf &text, const SWKey *key, const SWModu
                         case SE_GLAGOLITIC:
 				addTrans("Latin-Glagolitic", &ID);
                                 break;
-                        case SE_TENGWAR:
-				addTrans("Latin-Tengwar", &ID);
-                                break;
-                        case SE_CIRTH:
-				addTrans("Latin-Cirth", &ID);
-                                break;
+//                        case SE_TENGWAR:
+//				addTrans("Latin-Tengwar", &ID);
+//                                break;
+//                        case SE_CIRTH:
+//				addTrans("Latin-Cirth", &ID);
+//                                break;
                         }
                 }
 
