@@ -50,18 +50,37 @@ bool zLD::isWritable() {
  */
 
 void zLD::strongsPad(char *buf) {
-	const char *check;
-	long size = 0;
+	char *check;
+	int size = 0;
 	int len = strlen(buf);
-	if ((len < 5) && (len > 0)) {
-		for (check = buf; *check; check++) {
+	char subLet = 0;
+	bool bang = false;
+	if ((len < 8) && (len > 0)) {
+		for (check = buf; *(check+1); check++) {
 			if (!isdigit(*check))
 				break;
 			else size++;
 		}
 
-		if ((size == len) && size) 
+		if (size && ((size == (len-1)) || (size == (len-2)))) {
+			if (*check == '!') {
+				bang = true;
+				check++;
+			}
+			if (isalpha(*check)) {
+				subLet = toupper(*check);
+				*(check-(bang?1:0)) = 0;
+			}
 			sprintf(buf, "%.5d", atoi(buf));
+			if (subLet) {
+				check = buf+(strlen(buf));
+				if (bang) {
+					*check++ = '!';
+				}
+				*check++ = subLet;
+				*check = 0;
+			}
+		}
 	}
 }
 
