@@ -485,35 +485,11 @@ ListKey &SWModule::search(const char *istr, int searchType, int flags, SWKey *sc
 		wchar_t wcharBuffer[MAX_CONV_SIZE + 1];
 		char utfBuffer[MAX_CONV_SIZE + 1];
 		
-		
-		// Make sure our scope for this search is bounded by
-		// something we can test
-		// In the future, add bool SWKey::isValid(const char *tryString);
-		bool freeTestKey = false;
-
-		// only enforce range if we're VerseKey decendant
-		bool enforceRange = SWDYNAMIC_CAST(VerseKey, resultKey);
-
-		SWKey *testKey = 0;
-		if (enforceRange) {
-			SWTRY {
-				testKey = SWDYNAMIC_CAST(VerseKey, ((scope)?scope:key));
-				if (!testKey) {
-					testKey = SWDYNAMIC_CAST(ListKey, ((scope)?scope:key));
-				}
-			}
-			SWCATCH ( ... ) {}
-			if (!testKey) {
-				testKey = new ListKey();
-				*testKey = ((VerseKey *)resultKey)->ParseVerseList((const char *)((scope)?scope:key), *resultKey, true);
-				freeTestKey = true;
-			}
-		}
 		lucene::index::IndexReader    *ir = 0;
 		lucene::search::IndexSearcher *is = 0;
-		Query                          *q = 0;
-		Hits                           *h = 0;
-		try {
+		Query                         *q  = 0;
+		Hits                          *h  = 0;
+		SWTRY {
 			ir = IndexReader::open(target);
 			is = new IndexSearcher(ir);
 			(*percent)(10, percentUserData);
@@ -532,25 +508,17 @@ ListKey &SWModule::search(const char *istr, int searchType, int flags, SWKey *sc
 				// set a temporary verse key to this module position
 				lucene_wcstoutf8(utfBuffer, doc.get(_T("key")), MAX_CONV_SIZE);	
 				*resultKey = utfBuffer; //TODO Does a key always accept utf8?
-				if (enforceRange) {
-					// check scope
-					// Try to set our scope key to this verse key
-					*testKey = *resultKey;
 
-					// check to see if it set ok and if so, add to our return list
-					if (*testKey == *resultKey) {
-						listKey << *resultKey;
-						listKey.GetElement()->userData = (void *)((__u32)(h->score(i)*100));
-					}
-				}
-				else {
+				// check to see if it sets ok (in our range?) and if so, add to our return list
+				*getKey() = *resultKey;
+				if (*getKey() == *resultKey) {
 					listKey << *resultKey;
 					listKey.GetElement()->userData = (void *)((__u32)(h->score(i)*100));
 				}
 			}
 			(*percent)(98, percentUserData);
 		}
-		catch (...) {
+		SWCATCH (...) {
 			q = 0;
 			// invalid clucene query
 		}
@@ -561,9 +529,6 @@ ListKey &SWModule::search(const char *istr, int searchType, int flags, SWKey *sc
 		if (ir) {
 			ir->close();
 		}
-		if (freeTestKey) {
-			delete testKey;
-		}
 	}
 #endif
 
@@ -641,6 +606,7 @@ ListKey &SWModule::search(const char *istr, int searchType, int flags, SWKey *sc
 		if (searchType >= 0) {
 			if (!regexec(&preg,  StripText(), 0, 0, 0)) {
 				*resultKey = *getKey();
+				resultKey->clearBound();
 				listKey << *resultKey;
 			}
 		}
@@ -657,6 +623,7 @@ ListKey &SWModule::search(const char *istr, int searchType, int flags, SWKey *sc
 				sres = strstr(textBuf.c_str(), term.c_str());
 				if (sres) { //it's also in the StripText(), so we have a valid search result item now
 					*resultKey = *getKey();
+					resultKey->clearBound();
 					listKey << *resultKey;
 				}
 				break;
@@ -683,6 +650,7 @@ ListKey &SWModule::search(const char *istr, int searchType, int flags, SWKey *sc
 				
 				if ((loopCount == 2) && (foundWords == words.size())) { //we found the right words in both raw and stripped text, which means it's a valid result item
 					*resultKey = *getKey();
+					resultKey->clearBound();
 					listKey << *resultKey;
 				}
 				} break;
@@ -738,6 +706,7 @@ ListKey &SWModule::search(const char *istr, int searchType, int flags, SWKey *sc
 								}
 								if (sres) {
 									*resultKey = *getKey();
+									resultKey->clearBound();
 									listKey << *resultKey;
 									break;
 								}
@@ -811,7 +780,7 @@ const char *SWModule::StripText(const char *buf, int len) {
 
 	SWBuf &tmpbuf = (buf) ? local : getRawEntryBuf();
 	SWKey *key = 0;
-	static char *null = "";
+	static const char *null = "";
 
 	if (tmpbuf) {
 		unsigned long size = (len < 0) ? ((getEntrySize()<0) ? strlen(tmpbuf) : getEntrySize()) : len;
