@@ -11,7 +11,9 @@
 #include <unistd.h>
 #endif
 
+#include <filemgr.h>
 #include <zipcomprs.h>
+
 #ifndef NO_SWORD_NAMESPACE
 using namespace sword;
 #endif
@@ -35,14 +37,10 @@ FileCompress::FileCompress(char *fname)
 {
 	char buf[256];
 
-#ifndef O_BINARY
-#define O_BINARY 0
-#endif
-
-	ufd  = open(fname, O_RDWR|O_CREAT|O_BINARY, 00644);
+	ufd  = FileMgr::createPathAndFile(fname);
 
 	sprintf(buf, "%s.zip", fname);
-	zfd = open(buf, O_RDWR|O_CREAT|O_BINARY, 00644);
+	zfd = FileMgr::createPathAndFile(buf);
 }
 
 	
@@ -83,7 +81,7 @@ void FileCompress::Decode()
 }
 
 
-main(int argc, char **argv)
+int main(int argc, char **argv)
 {
 	int decomp = 0;
 	SWCompress *fobj;
@@ -107,4 +105,5 @@ main(int argc, char **argv)
 	else fobj->Encode();
 
 	delete fobj;
+	return 0;
 }
