@@ -19,9 +19,7 @@
 #include <utilxml.h>
 #include <versekey.h>
 #include <swmodule.h>
-#ifdef WIN32
 #include <ctype.h>
-#endif
 
 SWORD_NAMESPACE_START
 
